agentle.mcp.session\_management.in\_memory
==========================================

.. automodule:: agentle.mcp.session_management.in_memory

   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      InMemorySessionManager
      SessionManager
   